<?php
/**
 * EW Social Widget
 */
if(!class_exists('WP_Widget_WD_featured_post')){
	class WP_Widget_WD_featured_post extends WP_Widget {
		private $length = 20;

		function __construct() {
			$widgetOps = array('classname' => 'widget_featured_post', 'description' => __('Display Featured Post','wpdance'));
			$controlOps = array('width' => 400, 'height' => 550);
		   	parent::__construct('widget_featured_post', __('WD - Featured Post','wpdance'), $widgetOps, $controlOps);
		}
		
		
		function widget( $args, $instance ) {
			extract($args);
			$title = esc_attr($instance['title']);
			$title = (strlen($title) <= 0 ? 'Featured Post' : $title);
			$post_id = ($instance['post_id'])?esc_attr( $instance['post_id'] ):'';
			$word_limit = ($instance['word_limit'])?esc_attr( $instance['word_limit'] ):'';
			$this->length = $word_limit;
			$fpw_arrg = 'p=' . $post_id;
			
			if ( $fpw_arrg == 'p=' ){
				$fpw_arrg = 'posts_per_page=1&orderby=rand';
			}
			
			$fpw_post = new WP_Query( $fpw_arrg );
			
			echo $before_widget;
			echo $before_title . $title . $after_title;
			
			while( $fpw_post->have_posts() ) :
				$fpw_post->the_post();
				global $post;
				
				$num_comments = get_comments_number();
				if ( comments_open() ) {
					if ( $num_comments == 0 ) {
						$comments = __('No comments', 'wpdance');
					} elseif ( $num_comments > 1 ) {
						$comments = $num_comments . __(' comments', 'wpdance');
					} else {
						$comments = __('1 comment', 'wpdance');
					}
					$write_comments = '<a href="' . get_comments_link() .'">'. $comments.'</a>';
				}
				
				
			?>
				<div class="detail">
					
					<div class="entry-title">
						
						<a class="wrapper_img" href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'wpdance' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark">
							<?php echo get_the_post_thumbnail( $post->ID, 'thumbnail');?>
							<span class="wrapper_comments_number" title="<?php comments_number( __('no comment', 'wpdance'), '1 comment', '% comments');?>"><?php comments_number('0', '1', '%');?></span>
						</a>
						
						<h2 class="heading-title">
							<a class="widget-f-post-title post-title heading-title" href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'wpdance' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark">						
								<span><?php echo esc_attr(get_the_title()); ?></span>
							</a>
						</h2>
						
					</div>
					
					<div class="entry-desc">
						<?php
						add_filter( 'excerpt_length', array($this,'custom_excerpt_length'), 999);
						the_excerpt();
						?>
						
					</div>
					<ul class="entry-meta list-inline">
						<li class="entry-date">Written on <?php echo get_the_date(get_option('date_format_blog')); ?></li>
					</ul>
				</div>
			<?php
			endwhile;
			
			echo $after_widget;
		}
		
		public function custom_excerpt_length( $length ) {
			return $this->length;
		}
		
		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;		
			$instance['title'] = $new_instance['title'];
			$instance['post_id'] =  $new_instance['post_id'];		
			$instance['word_limit'] =  $new_instance['word_limit'];
			return $instance;
		}

		function form( $instance ) { 
			$instance = wp_parse_args( (array) $instance, array( 'title' => 'Featured Post', 
																 'post_id' => null, 'word_limit' => '20' ) );
			$title = esc_attr($instance['title']);
			$post_id = esc_attr($instance['post_id']);
			$word_limit = ($instance['word_limit'])? esc_attr($instance['word_limit']): '';
			
			$args = array(
				'posts_per_page' => -1,
				'post_status' => 'publish'
			);
			
			$post_options = '<option value="">'. __('Take a random post','wpdance') .'</option>';
			$features = get_posts($args);
			foreach ( $features as $feature ){
				if( $feature->ID != $post_id ){
					$post_options .= '<option value="'. $feature->ID .'">'. $feature->post_title .'</option>';
				}
				else {
					$post_options .= '<option value="'. $feature->ID .'" selected="selected">'. $feature->post_title .'</option>';
				}
			}
			
		?>
			<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Enter your title','wpdance'); ?> : </label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>
			
			<p><label for="<?php echo $this->get_field_id('post_id'); ?>"><?php _e('Choose your post','wpdance'); ?> : </label>
			<select class="widefat" id="<?php echo $this->get_field_id('post_id'); ?>" name="<?php echo $this->get_field_name('post_id'); ?>">
				<?php echo $post_options; ?>
			</select>
			</p>
			
			<p><label for="<?php echo $this->get_field_id('word_limit'); ?>"><?php _e('Introtext word limit','wpdance'); ?> : </label>
			<input class="widefat" id="<?php echo $this->get_field_id('word_limit'); ?>" name="<?php echo $this->get_field_name('word_limit'); ?>" type="number" value="<?php echo esc_attr($word_limit); ?>" /></p>
			</p>
			
			<?php }
	}
}



